<?php
namespace FlizVideoGenerator\Admin;

class BulkGenerator {
    private $post_list;

    public function __construct() {
        add_action('admin_enqueue_scripts', [$this, 'enqueue_scripts']);
        add_action('wp_ajax_fliz_bulk_generate_videos', [$this, 'handle_bulk_generation']);
        
        // Charger WP_List_Table
        if (!class_exists('WP_List_Table')) {
            require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
        }
    }

    public function init() {
        $this->post_list = new PostList();
    }

    public function handle_bulk_generation() {
        check_ajax_referer('fliz_bulk_generator_nonce', 'nonce');

        if (!current_user_can('manage_options')) {
            wp_send_json_error($this->get_localized_message('permission_denied'));
        }

        // Vérification de la clé API
        $api = new \FlizVideoGenerator\Api\FlizApi();
        if (!get_option('fliz_api_key')) {
            wp_send_json_error($this->get_localized_message('no_api_key'));
        }

        // Vérification des crédits disponibles
        $credits = $api->get_credits();
        if (is_wp_error($credits)) {
            wp_send_json_error($this->get_localized_message('api_error'));
        }

        if ($credits <= 0) {
            wp_send_json_error($this->get_localized_message('no_credits'));
        }

        $post_ids = isset($_POST['posts']) ? array_map('intval', $_POST['posts']) : [];
        if (empty($post_ids)) {
            wp_send_json_error($this->get_localized_message('no_posts_selected'));
        }

        // Vérification si assez de crédits pour tous les articles
        if (count($post_ids) > $credits) {
            wp_send_json_error($this->get_localized_message('not_enough_credits'));
        }

        $video_type = sanitize_text_field($_POST['video_type']);
        $video_format = sanitize_text_field($_POST['video_format']);

        $errors = [];

        foreach ($post_ids as $post_id) {
            $post = get_post($post_id);
            if (!$post) continue;

            $input = [
                'post_id' => $post_id,
                'name' => $post->post_title,
                'description' => wp_strip_all_tags($post->post_content),
                'site_url' => get_permalink($post_id),
                'site_name' => get_bloginfo('name'),
                'lang' => substr(get_locale(), 0, 2),
                'format' => $video_format,
                'category' => $video_type
            ];

            $result = $api->create_video($input);

            if (is_wp_error($result)) {
                $errors[] = sprintf(
                    __('Erreur pour l\'article "%s": %s', 'fliz-video-generator'),
                    $post->post_title,
                    $result->get_error_message()
                );
                continue;
            }

            if (!isset($result['fliz_video_create']['video_id'])) {
                $errors[] = sprintf(
                    __('Erreur pour l\'article "%s": ID de vidéo manquant', 'fliz-video-generator'),
                    $post->post_title
                );
                continue;
            }

            $video_id = $result['fliz_video_create']['video_id'];
            update_post_meta($post_id, '_fliz_video_id', $video_id);

            // Ajouter le shortcode à la fin de l'article
            $content = $post->post_content;
            if (substr($content, -1) !== "\n") {
                $content .= "\n";
            }
            $content .= "\n[fliz_video id=\"" . $video_id . "\"]";

            // Mettre à jour le contenu de l'article
            wp_update_post([
                'ID' => $post_id,
                'post_content' => $content
            ]);

            // Logger la génération
            \FlizVideoGenerator\Logger\VideoLogger::log(
                $post_id,
                $video_id,
                'pending',
                __('Génération de vidéo initiée via la génération en masse', 'fliz-video-generator')
            );
        }

        if (!empty($errors)) {
            wp_send_json_error(implode("\n", $errors));
        }

        wp_send_json_success(__('Les vidéos sont en cours de génération.', 'fliz-video-generator'));
    }

    private function get_localized_message($key) {
        $locale = get_locale();
        $messages = [
            'permission_denied' => [
                'fr_FR' => 'Permission refusée',
                'es_ES' => 'Permiso denegado',
                'it_IT' => 'Permesso negato',
                'de_DE' => 'Zugriff verweigert',
                'pt_PT' => 'Permissão negada',
                'default' => 'Permission denied'
            ],
            'no_api_key' => [
                'fr_FR' => 'Vous devez configurer une clé API avant de lancer la génération de vos vidéos',
                'es_ES' => 'Debe configurar una clave API antes de generar sus videos',
                'it_IT' => 'È necessario configurare una chiave API prima di generare i video',
                'de_DE' => 'Sie müssen einen API-Schlüssel konfigurieren, bevor Sie Videos generieren können',
                'pt_PT' => 'Você deve configurar uma chave API antes de gerar seus vídeos',
                'default' => 'You must configure an API key before generating your videos'
            ],
            'no_credits' => [
                'fr_FR' => 'Attention, vous n\'avez plus de crédits Fliz. Veuillez changer de plan pour générer de nouvelles vidéos.',
                'es_ES' => 'Atención, no tiene más créditos Fliz. Cambie su plan para generar nuevos videos.',
                'it_IT' => 'Attenzione, non hai più crediti Fliz. Cambia piano per generare nuovi video.',
                'de_DE' => 'Achtung, Sie haben keine Fliz-Credits mehr. Bitte ändern Sie Ihren Plan, um neue Videos zu generieren.',
                'pt_PT' => 'Atenção, você não tem mais créditos Fliz. Por favor, mude seu plano para gerar novos vídeos.',
                'default' => 'Warning, you have no more Fliz credits. Please upgrade your plan to generate new videos.'
            ],
            'not_enough_credits' => [
                'fr_FR' => 'Attention, vous n\'avez plus assez de crédits Fliz pour générer l\'ensemble des vidéos. Veuillez changer de plan avant de relancer la génération.',
                'es_ES' => 'Atención, no tiene suficientes créditos Fliz para generar todos los videos. Cambie su plan antes de reiniciar la generación.',
                'it_IT' => 'Attenzione, non hai abbastanza crediti Fliz per generare tutti i video. Cambia piano prima di riavviare la generazione.',
                'de_DE' => 'Achtung, Sie haben nicht genügend Fliz-Credits, um alle Videos zu generieren. Bitte ändern Sie Ihren Plan, bevor Sie die Generierung neu starten.',
                'pt_PT' => 'Atenção, você não tem créditos Fliz suficientes para gerar todos os vídeos. Por favor, mude seu plano antes de reiniciar a geração.',
                'default' => 'Warning, you don\'t have enough Fliz credits to generate all videos. Please upgrade your plan before restarting generation.'
            ],
            'api_error' => [
                'fr_FR' => 'Erreur lors de la vérification des crédits',
                'es_ES' => 'Error al verificar los créditos',
                'it_IT' => 'Errore durante la verifica dei crediti',
                'de_DE' => 'Fehler bei der Überprüfung der Credits',
                'pt_PT' => 'Erro ao verificar os créditos',
                'default' => 'Error checking credits'
            ],
            'no_posts_selected' => [
                'fr_FR' => 'Aucun article sélectionné',
                'es_ES' => 'Ningún artículo seleccionado',
                'it_IT' => 'Nessun articolo selezionato',
                'de_DE' => 'Keine Artikel ausgewählt',
                'pt_PT' => 'Nenhum artigo selecionado',
                'default' => 'No posts selected'
            ]
        ];

        return $messages[$key][$locale] ?? $messages[$key]['default'];
    }

    public function enqueue_scripts($hook) {
        if (!isset($_GET['page']) || $_GET['page'] !== 'fliz-video-bulk') {
            return;
        }

        wp_enqueue_style(
            'fliz-bulk-generator',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/css/bulk-generator.css',
            [],
            FLIZ_VIDEO_GENERATOR_VERSION
        );

        wp_enqueue_script(
            'fliz-bulk-generator',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/js/bulk-generator.js',
            ['jquery'],
            FLIZ_VIDEO_GENERATOR_VERSION,
            true
        );

        $locale = get_locale();
        $translations = [
            'selectPosts' => [
                'fr_FR' => 'Veuillez sélectionner au moins un article',
                'es_ES' => 'Por favor, seleccione al menos un artículo',
                'it_IT' => 'Seleziona almeno un articolo',
                'de_DE' => 'Bitte wählen Sie mindestens einen Artikel aus',
                'pt_PT' => 'Por favor, selecione pelo menos um artigo',
                'default' => 'Please select at least one post'
            ],
            'confirmGeneration' => [
                'fr_FR' => 'Êtes-vous sûr de vouloir générer des vidéos pour les articles sélectionnés ?',
                'es_ES' => '¿Está seguro de que desea generar videos para los artículos seleccionados?',
                'it_IT' => 'Sei sicuro di voler generare video per gli articoli selezionati?',
                'de_DE' => 'Sind Sie sicher, dass Sie Videos für die ausgewählten Artikel generieren möchten?',
                'pt_PT' => 'Tem certeza de que deseja gerar vídeos para os artigos selecionados?',
                'default' => 'Are you sure you want to generate videos for the selected posts?'
            ],
            'generating' => [
                'fr_FR' => 'Génération en cours...',
                'es_ES' => 'Generando...',
                'it_IT' => 'Generazione in corso...',
                'de_DE' => 'Generierung läuft...',
                'pt_PT' => 'Gerando...',
                'default' => 'Generating...'
            ],
            'success' => [
                'fr_FR' => 'Les vidéos sont en cours de création et seront disponibles dans quelques minutes.',
                'es_ES' => 'Los videos se están creando y estarán disponibles en unos minutos.',
                'it_IT' => 'I video sono in fase di creazione e saranno disponibili tra pochi minuti.',
                'de_DE' => 'Die Videos werden erstellt und sind in wenigen Minuten verfügbar.',
                'pt_PT' => 'Os vídeos estão sendo criados e estarão disponíveis em alguns minutos.',
                'default' => 'The videos are being created and will be available in a few minutes.'
            ],
            'error' => [
                'fr_FR' => 'Erreur lors de la génération',
                'es_ES' => 'Error durante la generación',
                'it_IT' => 'Errore durante la generazione',
                'de_DE' => 'Fehler bei der Generierung',
                'pt_PT' => 'Erro durante a geração',
                'default' => 'Error during generation'
            ],
            'generateText' => [
                'fr_FR' => 'Générer',
                'es_ES' => 'Generar',
                'it_IT' => 'Genera',
                'de_DE' => 'Generieren',
                'pt_PT' => 'Gerar',
                'default' => 'Generate'
            ]
        ];

        $getText = function($key) use ($translations, $locale) {
            return $translations[$key][$locale] ?? $translations[$key]['default'];
        };

        wp_localize_script('fliz-bulk-generator', 'flizBulk', [
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('fliz_bulk_generator_nonce'),
            'selectPosts' => $getText('selectPosts'),
            'confirmGeneration' => $getText('confirmGeneration'),
            'generating' => $getText('generating'),
            'success' => $getText('success'),
            'error' => $getText('error'),
            'generateText' => $getText('generateText')
        ]);
    }

    public function render_page() {
        // Initialiser la liste des articles
        $this->init();
        
        $locale = get_locale();
        
        $translations = [
            'page_title' => [
                'fr_FR' => 'Générer des vidéos',
                'es_ES' => 'Generar videos',
                'it_IT' => 'Genera video',
                'de_DE' => 'Videos generieren',
                'pt_PT' => 'Gerar vídeos',
                'default' => 'Generate videos'
            ],
            'select_posts' => [
                'fr_FR' => 'Sélectionnez les articles pour lesquels vous souhaitez générer des vidéos.',
                'es_ES' => 'Seleccione los artículos para los que desea generar videos.',
                'it_IT' => 'Seleziona gli articoli per i quali vuoi generare i video.',
                'de_DE' => 'Wählen Sie die Artikel aus, für die Sie Videos generieren möchten.',
                'pt_PT' => 'Selecione os artigos para os quais deseja gerar vídeos.',
                'default' => 'Select the posts for which you want to generate videos.'
            ],
            'search' => [
                'fr_FR' => 'Rechercher',
                'es_ES' => 'Buscar',
                'it_IT' => 'Cerca',
                'de_DE' => 'Suchen',
                'pt_PT' => 'Pesquisar',
                'default' => 'Search'
            ],
            'config_title' => [
                'fr_FR' => 'Configuration de la génération',
                'es_ES' => 'Configuración de la generación',
                'it_IT' => 'Configurazione della generazione',
                'de_DE' => 'Generierungskonfiguration',
                'pt_PT' => 'Configuração da geração',
                'default' => 'Generation configuration'
            ],
            'video_type' => [
                'fr_FR' => 'Type de vidéo :',
                'es_ES' => 'Tipo de video:',
                'it_IT' => 'Tipo di video:',
                'de_DE' => 'Videotyp:',
                'pt_PT' => 'Tipo de vídeo:',
                'default' => 'Video type:'
            ],
            'article' => [
                'fr_FR' => 'Article',
                'es_ES' => 'Artículo',
                'it_IT' => 'Articolo',
                'de_DE' => 'Artikel',
                'pt_PT' => 'Artigo',
                'default' => 'Article'
            ],
            'ad' => [
                'fr_FR' => 'Publicité',
                'es_ES' => 'Publicidad',
                'it_IT' => 'Pubblicità',
                'de_DE' => 'Werbung',
                'pt_PT' => 'Publicidade',
                'default' => 'Advertisement'
            ],
            'product' => [
                'fr_FR' => 'Produit',
                'es_ES' => 'Producto',
                'it_IT' => 'Prodotto',
                'de_DE' => 'Produkt',
                'pt_PT' => 'Produto',
                'default' => 'Product'
            ],
            'format' => [
                'fr_FR' => 'Format :',
                'es_ES' => 'Formato:',
                'it_IT' => 'Formato:',
                'de_DE' => 'Format:',
                'pt_PT' => 'Formato:',
                'default' => 'Format:'
            ],
            'square' => [
                'fr_FR' => 'Carré',
                'es_ES' => 'Cuadrado',
                'it_IT' => 'Quadrato',
                'de_DE' => 'Quadratisch',
                'pt_PT' => 'Quadrado',
                'default' => 'Square'
            ],
            'cancel' => [
                'fr_FR' => 'Annuler',
                'es_ES' => 'Cancelar',
                'it_IT' => 'Annulla',
                'de_DE' => 'Abbrechen',
                'pt_PT' => 'Cancelar',
                'default' => 'Cancel'
            ],
            'generate' => [
                'fr_FR' => 'Générer',
                'es_ES' => 'Generar',
                'it_IT' => 'Genera',
                'de_DE' => 'Generieren',
                'pt_PT' => 'Gerar',
                'default' => 'Generate'
            ]
        ];

        $getText = function($key) use ($translations, $locale) {
            return $translations[$key][$locale] ?? $translations[$key]['default'];
        };
        
        ?>
        <div class="wrap">
            <h1><?php echo esc_html($getText('page_title')); ?></h1>
            
            <div class="notice notice-info">
                <p><?php echo esc_html($getText('select_posts')); ?></p>
            </div>

            <form id="posts-filter" method="get">
                <input type="hidden" name="page" value="fliz-video-bulk">
                <?php
                $this->post_list->prepare_items();
                $this->post_list->search_box($getText('search'), 'post');
                $this->post_list->display();
                ?>
            </form>
        </div>

        <!-- Modal de configuration -->
        <div id="fliz-generator-modal" class="fliz-modal" style="display: none;">
            <div class="fliz-modal-content">
                <h2><?php echo esc_html($getText('config_title')); ?></h2>
                
                <div class="fliz-modal-body">
                    <p>
                        <label><?php echo esc_html($getText('video_type')); ?></label><br>
                        <select name="video_type" id="fliz-video-type">
                            <option value="article"><?php echo esc_html($getText('article')); ?></option>
                            <option value="ad"><?php echo esc_html($getText('ad')); ?></option>
                            <option value="product"><?php echo esc_html($getText('product')); ?></option>
                        </select>
                    </p>

                    <p>
                        <label><?php echo esc_html($getText('format')); ?></label><br>
                        <select name="video_format" id="fliz-video-format">
                            <option value="size_16_9">16:9</option>
                            <option value="size_9_16">9:16</option>
                            <option value="square"><?php echo esc_html($getText('square')); ?></option>
                        </select>
                    </p>
                </div>

                <div class="fliz-modal-footer">
                    <button type="button" class="button button-secondary fliz-modal-close">
                        <?php echo esc_html($getText('cancel')); ?>
                    </button>
                    <button type="button" class="button button-primary" id="fliz-generate-videos">
                        <?php echo esc_html($getText('generate')); ?>
                    </button>
                </div>
            </div>
        </div>
        <?php
    }
} 