<?php
namespace FlizVideoGenerator\Admin;

class Settings {
    private $error_message = '';
    private $success_message = '';

    public function __construct() {
        add_action('admin_post_save_fliz_api_key', [$this, 'handle_form_submission']);
    }

    public function handle_form_submission() {
        if (!current_user_can('manage_options')) {
            wp_die(__('Vous n\'avez pas les permissions nécessaires pour effectuer cette action.', 'fliz-video-generator'));
        }

        if (!isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'save_fliz_api_key')) {
            wp_die(__('Action non autorisée.', 'fliz-video-generator'));
        }

        $api_key = isset($_POST['fliz_api_key']) ? sanitize_text_field($_POST['fliz_api_key']) : '';

        if (empty($api_key)) {
            set_transient('fliz_api_key_error', __('La clé API ne peut pas être vide.', 'fliz-video-generator'), 30);
            wp_redirect(admin_url('admin.php?page=fliz-video&error=1'));
            exit;
        }

        $api = new \FlizVideoGenerator\Api\FlizApi($api_key);
        $test = $api->test_connection();

        if (is_wp_error($test)) {
            set_transient('fliz_api_key_error', __('Votre clé API n\'est pas valide', 'fliz-video-generator'), 30);
            wp_redirect(admin_url('admin.php?page=fliz-video&error=1'));
            exit;
        }

        update_option('fliz_api_key', $api_key);
        set_transient('fliz_api_key_success', __('Clé API enregistrée avec succès.', 'fliz-video-generator'), 30);
        wp_redirect(admin_url('admin.php?page=fliz-video&updated=1'));
        exit;
    }

    public function render_settings_page() {
        // Récupération des messages
        $error_message = get_transient('fliz_api_key_error');
        $success_message = get_transient('fliz_api_key_success');
        
        // Suppression des transients après récupération
        if ($error_message) delete_transient('fliz_api_key_error');
        if ($success_message) delete_transient('fliz_api_key_success');
        
        $locale = get_locale();
        
        // Traductions pour le titre de la page
        $page_title_texts = [
            'fr_FR' => 'Gestion de la clé API Fliz',
            'es_ES' => 'Gestión de la clave API de Fliz',
            'it_IT' => 'Gestione della chiave API Fliz',
            'de_DE' => 'Fliz API-Schlüssel Verwaltung',
            'pt_PT' => 'Gestão da chave API Fliz',
            'default' => 'Fliz API Key Management'
        ];
        
        // Traductions pour la description
        $description_texts = [
            'fr_FR' => 'Créez des vidéos en 1 clic grâce à l\'IA de Fliz et insérez vos vidéos directement dans vos articles WordPress.',
            'es_ES' => 'Cree videos con un clic usando la IA de Fliz e insértelos directamente en sus artículos de WordPress.',
            'it_IT' => 'Crea video con un clic utilizzando l\'IA di Fliz e inseriscili direttamente nei tuoi articoli WordPress.',
            'de_DE' => 'Erstellen Sie Videos mit einem Klick mithilfe der Fliz KI und fügen Sie sie direkt in Ihre WordPress-Artikel ein.',
            'pt_PT' => 'Crie vídeos com um clique usando a IA do Fliz e insira-os diretamente em seus artigos WordPress.',
            'default' => 'Create videos in 1 click using Fliz AI and insert them directly into your WordPress posts.'
        ];

        $get_api_key_texts = [
            'fr_FR' => 'Obtenez votre clé API en vous inscrivant sur',
            'es_ES' => 'Obtenga su clave API registrándose en',
            'it_IT' => 'Ottieni la tua chiave API registrandoti su',
            'de_DE' => 'Erhalten Sie Ihren API-Schlüssel durch Registrierung auf',
            'pt_PT' => 'Obtenha sua chave API registrando-se em',
            'default' => 'Get your API key by signing up on'
        ];

        $save_button_texts = [
            'fr_FR' => 'Enregistrer',
            'es_ES' => 'Guardar',
            'it_IT' => 'Salvare',
            'de_DE' => 'Speichern',
            'pt_PT' => 'Salvar',
            'default' => 'Save'
        ];

        $credits_remaining_texts = [
            'fr_FR' => 'Il vous reste %d crédits vidéos.',
            'es_ES' => 'Le quedan %d créditos de video.',
            'it_IT' => 'Ti rimangono %d crediti video.',
            'de_DE' => 'Sie haben noch %d Videoguthaben.',
            'pt_PT' => 'Você tem %d créditos de vídeo restantes.',
            'default' => 'You have %d video credits remaining.'
        ];
        
        ?>
        <div class="wrap">
            <div style="display: flex; align-items: center; margin-bottom: 20px;">
                <img src="https://fliz.ai/wp-content/uploads/2023/07/Logo_Fliz-2.svg" 
                     alt="Fliz" 
                     style="height: 50px; margin-right: 20px;">
                <h1><?php echo esc_html($page_title_texts[$locale] ?? $page_title_texts['default']); ?></h1>
            </div>
            
            <div class="fliz-description" style="background: #fff; padding: 20px; margin-bottom: 20px; border-left: 4px solid #2271b1;">
                <p><?php echo esc_html($description_texts[$locale] ?? $description_texts['default']); ?></p>
                <p><?php echo esc_html($get_api_key_texts[$locale] ?? $get_api_key_texts['default']); ?> <a href="https://fliz.ai" target="_blank">Fliz.ai</a></p>
            </div>
            
            <div class="card" style="max-width: 600px;">
                <h2 class="title"><?php echo esc_html($api_key_titles[$locale] ?? $api_key_titles['default']); ?></h2>
                
                <form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>">
                    <input type="hidden" name="action" value="save_fliz_api_key">
                    <?php wp_nonce_field('save_fliz_api_key'); ?>
                    
                    <p>
                        <input type="text" id="fliz_api_key" name="fliz_api_key" 
                               value="<?php echo esc_attr(get_option('fliz_api_key')); ?>" 
                               class="regular-text" 
                               style="width: 100%;">
                        <?php if ($error_message): ?>
                            <span style="color: #dc3232; font-weight: bold; font-size: 12px; display: block; margin-top: 5px;">
                                <?php echo esc_html($error_message); ?>
                            </span>
                        <?php endif; ?>
                        <?php if ($success_message): ?>
                            <span style="color: #46b450; font-weight: bold; font-size: 12px; display: block; margin-top: 5px;">
                                <?php echo esc_html($success_message); ?>
                            </span>
                        <?php endif; ?>
                    </p>
                    
                    <?php submit_button($save_button_texts[$locale] ?? $save_button_texts['default']); ?>
                </form>
            </div>

            <?php
            $api = new \FlizVideoGenerator\Api\FlizApi();
            $credits = $api->get_credits();
            if (!is_wp_error($credits)) {
                echo '<p class="description" style="margin-top: 20px;">' . 
                     sprintf($credits_remaining_texts[$locale] ?? $credits_remaining_texts['default'], $credits) . 
                     '</p>';
            }
            ?>
        </div>
        <?php
    }

    private function get_localized_message($key) {
        $locale = get_locale();
        $messages = [
            'empty_key' => [
                'fr_FR' => 'La clé API ne peut pas être vide.',
                'es_ES' => 'La clave API no puede estar vacía.',
                'it_IT' => 'La chiave API non può essere vuota.',
                'de_DE' => 'Der API-Schlüssel darf nicht leer sein.',
                'pt_PT' => 'A chave API não pode estar vazia.',
                'default' => 'API key cannot be empty.'
            ],
            'invalid_key' => [
                'fr_FR' => 'Votre clé API n\'est pas valide',
                'es_ES' => 'Su clave API no es válida',
                'it_IT' => 'La tua chiave API non è valida',
                'de_DE' => 'Ihr API-Schlüssel ist ungültig',
                'pt_PT' => 'Sua chave API não é válida',
                'default' => 'Your API key is invalid'
            ],
            'success' => [
                'fr_FR' => 'Clé API enregistrée avec succès.',
                'es_ES' => 'Clave API guardada con éxito.',
                'it_IT' => 'Chiave API salvata con successo.',
                'de_DE' => 'API-Schlüssel erfolgreich gespeichert.',
                'pt_PT' => 'Chave API salva com sucesso.',
                'default' => 'API key successfully saved.'
            ]
        ];

        return $messages[$key][$locale] ?? $messages[$key]['default'];
    }
} 