<?php
namespace FlizVideoGenerator\Api;

class FlizApi {
    private $api_key;
    private $endpoint = 'https://api.fliz.ai/v1/graphql';

    public function __construct($api_key = null) {
        $this->api_key = $api_key ?: get_option('fliz_api_key');
    }

    public function create_video($input) {
        // Vérifier si la clé API est définie
        if (empty($this->api_key)) {
            $locale = get_locale();
            
            switch ($locale) {
                case 'fr_FR':
                    $message = 'Aucune clé API n\'a été configurée. Veuillez configurer votre clé API dans les %sréglages du plugin%s.';
                    break;
                case 'es_ES':
                    $message = 'No se ha configurado ninguna clave API. Configure su clave API en la %sconfiguración del plugin%s.';
                    break;
                case 'it_IT':
                    $message = 'Nessuna chiave API configurata. Configura la tua chiave API nelle %simpostazioni del plugin%s.';
                    break;
                default: // English
                    $message = 'No API key has been configured. Please configure your API key in the plugin %ssettings%s.';
                    break;
            }

            return new \WP_Error(
                'fliz_api_error',
                sprintf(
                    __($message, 'fliz-video-generator'),
                    '<a href="' . admin_url('options-general.php?page=fliz-video-generator') . '">',
                    '</a>'
                )
            );
        }

        error_log('Début de création de vidéo');
        error_log('Input reçu: ' . print_r($input, true));

        $query = 'mutation ($input: fliz_video_create_input!) {
            fliz_video_create(fliz_video_create_input: $input) {
                video_id
                cost
            }
        }';

        // S'assurer que toutes les valeurs sont des chaînes
        $formatted_input = [
            'name' => (string) substr($input['name'], 0, 255),
            'description' => (string) wp_strip_all_tags($input['description']),
            'format' => (string) strtolower($input['format']),
            'category' => (string) strtolower($input['category']),
            'lang' => (string) substr(get_locale(), 0, 2),
            'site_name' => (string) get_bloginfo('name'),
            'site_url' => (string) get_permalink($input['post_id'])
        ];

        // Supprimer les valeurs vides ou null
        $formatted_input = array_filter($formatted_input, function($value) {
            return $value !== '' && $value !== null;
        });

        // Gestion des images pour les types product et ad
        if (in_array($formatted_input['category'], ['product', 'ad'])) {
            $image_urls = [];
            
            // Image à la une
            $thumbnail_id = get_post_thumbnail_id($input['post_id']);
            if ($thumbnail_id) {
                $image_url = wp_get_attachment_url($thumbnail_id);
                if ($image_url) {
                    $image_urls[] = (string) $image_url;
                }
            }
            
            // Images de la galerie
            $gallery_images = $this->get_post_gallery_images($input['post_id']);
            foreach ($gallery_images as $url) {
                $image_urls[] = (string) $url;
            }
            
            // Images du contenu
            $post = get_post($input['post_id']);
            if ($post) {
                preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
                if (!empty($matches[1])) {
                    foreach ($matches[1] as $url) {
                        $image_urls[] = (string) $url;
                    }
                }
            }

            // S'assurer d'avoir au moins 3 images
            if (count($image_urls) < 3) {
                error_log('Erreur: pas assez d\'images trouvées');
                return new \WP_Error(
                    'fliz_api_error',
                    __('Au moins 3 images sont requises pour les vidéos de type produit ou publicité', 'fliz-video-generator')
                );
            }

            // Limiter à 10 images maximum et s'assurer que ce sont des chaînes uniques
            $image_urls = array_values(array_unique(array_map('strval', array_slice($image_urls, 0, 10))));
            $formatted_input['image_urls'] = $image_urls;
        }

        error_log('Input formaté: ' . print_r($formatted_input, true));

        // Utiliser graphql_request au lieu de faire la requête directement
        $result = $this->graphql_request($query, ['input' => $formatted_input]);

        if (is_wp_error($result)) {
            return $result;
        }

        return $result;
    }

    public function get_video_status($video_id) {
        $query = 'query ($id: uuid!) {
            fliz_video_by_pk(id: $id) {
                id
                url
                step
            }
        }';

        return $this->graphql_request($query, ['id' => $video_id]);
    }

    public function ajax_check_video_status() {
        check_ajax_referer('fliz_video_nonce', 'nonce');

        if (!isset($_POST['video_id'])) {
            wp_send_json_error();
        }

        $video_id = sanitize_text_field($_POST['video_id']);
        $result = $this->get_video_status($video_id);

        if (is_wp_error($result) || !isset($result['fliz_video_by_pk']['url'])) {
            wp_send_json_error();
        }

        wp_send_json_success([
            'url' => $result['fliz_video_by_pk']['url']
        ]);
    }

    private function graphql_request($query, $variables) {
        // Vérifier si la clé API est définie
        if (empty($this->api_key)) {
            $locale = get_locale();
            
            switch ($locale) {
                case 'fr_FR':
                    $message = 'Aucune clé API n\'a été configurée. Veuillez configurer votre clé API dans les %sréglages du plugin%s.';
                    break;
                case 'es_ES':
                    $message = 'No se ha configurado ninguna clave API. Configure su clave API en la %sconfiguración del plugin%s.';
                    break;
                case 'it_IT':
                    $message = 'Nessuna chiave API configurata. Configura la tua chiave API nelle %simpostazioni del plugin%s.';
                    break;
                default: // English
                    $message = 'No API key has been configured. Please configure your API key in the plugin %ssettings%s.';
                    break;
            }

            return new \WP_Error(
                'fliz_api_error',
                sprintf(
                    __($message, 'fliz-video-generator'),
                    '<a href="' . admin_url('options-general.php?page=fliz-video-generator') . '">',
                    '</a>'
                )
            );
        }

        $response = wp_remote_post($this->endpoint, [
            'headers' => [
                'Content-Type' => 'application/json',
                'Authorization' => 'Bearer ' . $this->api_key
            ],
            'body' => json_encode([
                'query' => $query,
                'variables' => $variables
            ]),
            'timeout' => 30
        ]);

        if (is_wp_error($response)) {
            return new \WP_Error('fliz_api_error', $response->get_error_message());
        }

        $status_code = wp_remote_retrieve_response_code($response);
        if ($status_code !== 200) {
            return new \WP_Error(
                'fliz_api_error',
                sprintf('Erreur HTTP %d: %s', $status_code, wp_remote_retrieve_response_message($response))
            );
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);
        
        if (defined('WP_DEBUG') && WP_DEBUG) {
            error_log('Réponse brute API Fliz: ' . wp_remote_retrieve_body($response));
            error_log('Réponse décodée API Fliz: ' . print_r($body, true));
        }

        if (json_last_error() !== JSON_ERROR_NONE) {
            $locale = get_locale();
            switch ($locale) {
                case 'fr_FR':
                    $message = 'Erreur de décodage JSON: %s';
                    break;
                case 'es_ES':
                    $message = 'Error de decodificación JSON: %s';
                    break;
                case 'it_IT':
                    $message = 'Errore di decodifica JSON: %s';
                    break;
                default:
                    $message = 'JSON decoding error: %s';
                    break;
            }
            return new \WP_Error('fliz_api_error', sprintf($message, json_last_error_msg()));
        }

        if (isset($body['errors'])) {
            $error_message = '';
            if (is_array($body['errors'])) {
                foreach ($body['errors'] as $error) {
                    if (isset($error['message'])) {
                        $error_message .= $error['message'] . '. ';
                    }
                }
            }
            if (empty($error_message)) {
                $error_message = 'Erreur inconnue de l\'API';
            }
            return new \WP_Error('fliz_api_error', $error_message);
        }

        if (!isset($body['data']) && !empty($body)) {
            return $body;
        }

        if (!isset($body['data'])) {
            $locale = get_locale();
            switch ($locale) {
                case 'fr_FR':
                    $message = 'Réponse invalide de l\'API';
                    break;
                case 'es_ES':
                    $message = 'Respuesta inválida de la API';
                    break;
                case 'it_IT':
                    $message = 'Risposta API non valida';
                    break;
                default:
                    $message = 'Invalid API response';
                    break;
            }
            return new \WP_Error('fliz_api_error', $message);
        }

        return $body['data'] ?? new \WP_Error('fliz_api_error', 'Réponse invalide de l\'API');
    }

    public function test_connection() {
        $query = '{__typename}';

        $response = wp_remote_post($this->endpoint, [
            'headers' => [
                'Content-Type' => 'application/json',
                'Authorization' => 'Bearer ' . $this->api_key
            ],
            'body' => json_encode(['query' => $query]),
            'timeout' => 30
        ]);

        if (is_wp_error($response)) {
            return new \WP_Error('fliz_api_error', 'Erreur de connexion: ' . $response->get_error_message());
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);

        if (json_last_error() !== JSON_ERROR_NONE) {
            return new \WP_Error('fliz_api_error', 'Erreur de décodage JSON: ' . json_last_error_msg());
        }

        if (isset($body['errors'])) {
            $error_message = implode(', ', array_column($body['errors'], 'message'));
            return new \WP_Error('fliz_api_error', 'Erreur API: ' . $error_message);
        }

        if (!isset($body['data']['__typename'])) {
            return new \WP_Error('fliz_api_error', 'Réponse invalide de l\'API');
        }

        return true;
    }

    // Fonction utilitaire pour récupérer les images de la galerie
    private function get_post_gallery_images($post_id) {
        $post = get_post($post_id);
        $gallery_images = [];
        
        if ($post) {
            $gallery = get_post_gallery($post, false);
            if (isset($gallery['ids'])) {
                $gallery_images_ids = explode(',', $gallery['ids']);
                foreach ($gallery_images_ids as $id) {
                    $url = wp_get_attachment_url($id);
                    if ($url) {
                        $gallery_images[] = $url;
                    }
                }
            }
        }
        
        return $gallery_images;
    }

    public function get_credits() {
        $query = 'query { fliz_app_subscription { monthly_credits lifetime_credits } }';

        $response = wp_remote_post($this->endpoint, [
            'headers' => [
                'Content-Type' => 'application/json',
                'Authorization' => 'Bearer ' . $this->api_key
            ],
            'body' => json_encode(['query' => $query]),
            'timeout' => 30
        ]);

        if (is_wp_error($response)) {
            return new \WP_Error('fliz_api_error', 'Erreur de connexion: ' . $response->get_error_message());
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);

        if (json_last_error() !== JSON_ERROR_NONE) {
            return new \WP_Error('fliz_api_error', 'Erreur de décodage JSON: ' . json_last_error_msg());
        }

        if (isset($body['errors'])) {
            $error_message = implode(', ', array_column($body['errors'], 'message'));
            return new \WP_Error('fliz_api_error', 'Erreur API: ' . $error_message);
        }

        $credits = 0;
        if (isset($body['data']['fliz_app_subscription'][0])) {
            $subscription = $body['data']['fliz_app_subscription'][0];
            $credits = $subscription['monthly_credits'] + $subscription['lifetime_credits'];
        }

        return $credits;
    }
} 